"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatCapsForServer = void 0;
const lodash_1 = __importDefault(require("lodash"));
const GECKO_CAP_PREFIXES = ['moz:'];
// https://www.w3.org/TR/webdriver/#capabilities
const STANDARD_CAPS = [
    'browserVersion',
    'platformName',
    'acceptInsecureCerts',
    'pageLoadStrategy',
    'proxy',
    'setWindowRect',
    'timeouts',
    'unhandledPromptBehavior',
];
function formatCapsForServer(caps) {
    const result = {};
    if (caps.browserName) {
        result.browserName = 'firefox';
    }
    for (const [name, value] of lodash_1.default.toPairs(caps)) {
        if (GECKO_CAP_PREFIXES.some((prefix) => name.startsWith(prefix)) || STANDARD_CAPS.includes(name)) {
            result[name] = value;
        }
    }
    if (result.platformName) {
        // Geckodriver only supports lowercase platform names
        result.platformName = lodash_1.default.toLower(result.platformName);
    }
    return result;
}
exports.formatCapsForServer = formatCapsForServer;
//# sourceMappingURL=utils.js.map